agentle.agents.errors.tool\_suspension\_error
=============================================

.. automodule:: agentle.agents.errors.tool_suspension_error

   
   .. rubric:: Classes

   .. autosummary::
   
      Any
   
   .. rubric:: Exceptions

   .. autosummary::
   
      ToolSuspensionError
   